/*
 * Shopalot Sample for DoJo Toolkit Tutorial
 * Author: Boris Fritscher
 * Date: Jan. 2007
 *
 * This file contains the complete Javascript/Dojo code.
 *
 */
//require statements
dojo.require("dojo.dnd.HtmlDragCopy");
dojo.require("dojo.event.*");
dojo.require("dojo.lfx.html");
dojo.require("dojo.json");
dojo.require("dojo.dom");
dojo.require("dojo.widget.*" );
dojo.require("dojo.widget.Dialog");
dojo.require("dojo.widget.LayoutContainer");
dojo.require("dojo.widget.ContentPane");
dojo.require("dojo.widget.Tooltip");
dojo.require("dojo.widget.Parse");
dojo.require("dojo.string.*");
//all dojo.require above this line
dojo.hostenv.writeIncludes(); //makes debugging in Venkman possible

dojo.addOnLoad(init); //function to execute when the page starts

// executed at start
function init(e) {
	//dialogHelp
	var dlgHelp = dojo.widget.byId("dialogHelp");
	var btn = document.getElementById("hider0");
	dlgHelp.setCloseControl(btn);

	//connect links
	var linkQuestion = dojo.byId("linkQuestion");
	dojo.event.connect(linkQuestion,'onclick',dlgHelp,"show");
	var linkBrowse = dojo.byId("linkBrowse");
	dojo.event.connect(linkBrowse,'onclick','browse');
	var linkCheckout = dojo.byId("linkCheckout");
	dojo.event.connect(linkCheckout,'onclick','checkout');

	//drag & drop: drop target
	var cart = dojo.byId("cart");
	var target = new dojo.dnd.HtmlDropTarget(cart, ["*"]);
	//redefine onDrop function of our target
	target.onDrop = function(e){
		//desactivate drag object
		this.onDragOut(e);
		var id = e.dragSource.dragObject.id;
		addItemToCart(id);
	};

	//reset cart session
	//(an improved solution would be to populate the cart with the values from the server)
	dojo.io.bind({
	    url: "getitems.php",
	    handler: function(type, data, evt){},
        mimetype: "text/plain",
	    content: {"action":"reset"}	});

	//show browse page
	browse();
}

function addItemToCart(itemId) {
	var bindArgs = {
		url: "getitems.php",
		handler: function(type, data, evt){
				 	var total = dojo.byId("total");
					if (data) {
						//update total
						total.innerHTML =  (parseFloat(data.price) + parseFloat(total.innerHTML)).toFixed(2);
						//create new item from the data
						var newLi = document.createElement("li");
						newLi.innerHTML = dojo.string.summary(data.name,15);
						var cartList = dojo.byId("cartList");
						//keep the list small
						if(cartList.getElementsByTagName("li").length >=5){
							dojo.dom.removeNode(cartList.firstChild);
						}
						//add item to the list
						cartList.appendChild(newLi);
					}
				  },
		mimetype: "text/json",
	  	content: {"action":"additem","itemid":itemId}
	 	};
	 //make the connection
	 dojo.io.bind(bindArgs);
}

function browse(){
	var contentPane = dojo.widget.byId("content");
	//populate list from db on load
	dojo.event.connect(contentPane, 'onLoad', getItems(''));
	contentPane.setUrl('browse.html');
}

function checkout(){
	var contentPane = dojo.widget.byId("content");
	contentPane.setUrl('form.html');
}

function getItems(keyword){
	var bindArgs = {
		url: "getitems.php",
		handler: updateCatalog,
		mimetype: "text/json",
		content: {"action":"search","keyword":keyword}
	 };
	 dojo.io.bind(bindArgs);
}

//create catalog from results provided by the server
function updateCatalog(type, data, evt){
	var catalog = dojo.byId("catalog");
	//empty the list
	dojo.dom.removeChildren(catalog);
	if (data) {
		for(var i=0;i<data.length; i++){
			//create the item
			var newLi = document.createElement("li");
			newLi.innerHTML = '<h2 style="font-size: 12px;margin:0;padding: 2px;text-align:left">'+data[i].name+' <span style="color:#c00;">'+data[i].price+'.-</span></h2><img src="items/'+data[i].id+'.jpg" alt="'+data[i].name+'"/>';
			newLi.id = data[i].id;
			newLi.style.listStyleType="none";
			//add the item
			catalog.appendChild(newLi);
			//make the item draggable
			var dnd = new dojo.dnd.HtmlDragCopySource(newLi, "*", true);
			//add a tooltip to the item
			var toolTip = dojo.widget.createWidget("Tooltip",{caption:data[i].description,connectId:data[i].id,showDelay:100});
			document.body.appendChild(toolTip.domNode);
		}
	}else{
		//case not result add an item as message
		var newLi2 = document.createElement("li");
		newLi2.innerHTML = '<h2 style="font-size: 12px;margin:0;padding: 2px;text-align:left; color:#c00;">Not matching item found!</h2>';
		newLi2.style.listStyleType="none";
		catalog.appendChild(newLi2);
	 }
}

//simple form validation before submit
function submit(){
	var myForm = dojo.byId("myForm");
	var firstname = dojo.widget.byId("firstname");
	var lastname = dojo.widget.byId("lastname");
	var email = dojo.widget.byId("email");

	if(!firstname.isMissing() & !lastname.isMissing() & email.isValid()){
		myForm.submit();
	} else{
		alert("There are some required fileds missing!");
	}
}